@@ -1,7 +1,8 @@
 #![forbid(unsafe_code)]
 #![deny(
+    clippy::dbg_macro,
     missing_copy_implementations,
-    missing_crate_level_docs,
+    rustdoc::missing_crate_level_docs,
     missing_debug_implementations,
     missing_docs,
     nonstandard_style,
